Index: _source/plugins/wysiwygarea/plugin.js
===================================================================
--- _source/plugins/wysiwygarea/plugin.js	(revision 6486)
+++ _source/plugins/wysiwygarea/plugin.js	(revision )
@@ -422,14 +422,9 @@
 			}
 
 			range.select();
-			// Notify non-IE that selection has changed.
-			if ( !CKEDITOR.env.ie )
-			{
-				// Make sure next selection change is correct.  (#6811)
-				editor.forceNextSelectionCheck();
-				editor.selectionChange();
+			// Cancel this selection change in favor of the next (correct).  (#6811)
+			evt.cancel();
-			}
+		}
-		}
 
 		// All browsers are incapable to moving cursor out of certain non-exitable
 		// blocks (e.g. table, list, pre) at the end of document, make this happen by
